@@ -31,6 +31,17 @@ import urllib.request
 import os
 import json
 
+# Don't remove this line.  The idna encoding
+# is used by getaddrinfo when dealing with unicode hostnames,
+# and in some cases, there appears to be a race condition
+# where threads will get a LookupError on getaddrinfo() saying
+# that the encoding doesn't exist.  Using the idna encoding before
+# running any CLI code (and any threads it may create) ensures that
+# the encodings.idna is imported and registered in the codecs registry,
+# which will stop the LookupErrors from happening.
+# See: https://bugs.python.org/issue29288
+u''.encode('idna')
+
 # determine if application is a script file or frozen exe
 if getattr(sys, 'frozen', False):
     template_folder=os.path.join(sys._MEIPASS, 'templates')
@@ -107,14 +118,23 @@ class MainWindow(QMainWindow):
         def trigger():
             self.browser.page().runJavaScript("flask.standalone.saveProject();")
         _save.triggered.connect(trigger)
+
         file.addSeparator()
 
-        _export = QAction(self.style().standardIcon(QStyle.SP_DialogSaveButton), "Export to static webpage",self)
+        _export = QAction(self.style().standardIcon(QStyle.SP_FileDialogListView), "Capture viewport",self)
+        file.addAction(_export)
+        def trigger():
+            self.browser.page().runJavaScript("flask.savePNG();")
+        _export.triggered.connect(trigger)
+        
+        _export = QAction(self.style().standardIcon(QStyle.SP_DirLinkIcon), "Export to static webpage",self)
         file.addAction(_export)
         def trigger():
             self.browser.page().runJavaScript("flask.standalone.exportToStatic();")
         _export.triggered.connect(trigger)
         
+        file.addSeparator()
+
         _exit = QAction(self.style().standardIcon(QStyle.SP_DialogCancelButton), "Exit",self)
         _exit.setShortcut("Ctrl+Q")
         file.addAction(_exit)
@@ -130,12 +150,12 @@ class MainWindow(QMainWindow):
             _plugin.triggered.connect(trigger)
         
         about = self.bar.addMenu("About")
-        _help = QAction("Help",self)
+        _help = QAction(self.style().standardIcon(QStyle.SP_DialogHelpButton), "Help",self)
         about.addAction(_help)
         def trigger():
             QDesktopServices.openUrl(QUrl("https://tissuumaps.github.io/"))
         _help.triggered.connect(trigger)
-        _version = QAction("Version",self)
+        _version = QAction(self.style().standardIcon(QStyle.SP_FileDialogInfoView), "Version",self)
         about.addAction(_version)
         def trigger():
             if getattr(sys, 'frozen', False):
@@ -254,9 +274,9 @@ class webEngine(QWebEngineView):
             
             print ("Impossible to load",self.location)
             time.sleep(0.1)
-        print ("loading page ", self.location)
+        #print ("loading page ", self.location)
         if (len(self.args) > 0):
-            if not self.openImagePath(self.args[0]):
+            if not self.openImagePath(os.path.abspath(self.args[0])):
                 self.load(QUrl(self.location))
         else:
             self.load(QUrl(self.location))
@@ -286,6 +306,8 @@ class webEngine(QWebEngineView):
             nonlocal imgFiles, otherFiles
             def addRelativePath_aux (state, path, isImg):
                 nonlocal imgFiles, otherFiles
+                if not path[0] in state.keys():
+                    return
                 if len(path) == 1:
                     if isinstance(state[path[0]], list):
                         if isImg:
@@ -303,8 +325,6 @@ class webEngine(QWebEngineView):
                             otherFiles += [state[path[0]]]
                             state[path[0]] = "data/files/" + os.path.basename(state[path[0]])
                     return
-                if not path[0] in state.keys():
-                    return
                 else:
                     if isinstance(state[path[0]], list):
                         for state_ in state[path[0]]:
