@@ -119,7 +119,6 @@ projectUtils.getActiveProject = function () {
         }
         var title = document.getElementById("generateButtonTitle").value
         var comment = document.getElementById("generateButtonComment").value
-        console.log(_exists);
         if (!_exists) {
             interfaceUtils.confirm("Warning, path doesn't seem accessible on the server.\n\nAre you sure you want to continue?")
             .then(function(_confirm) {
@@ -174,6 +173,15 @@ projectUtils.getActiveProject = function () {
  }
 
 
+projectUtils.updateMarkerButton = function(dataset) {
+    var data_obj = dataUtils.data[dataset];
+    var markerFile = projectUtils._activeState.markerFiles[data_obj["fromButton"]];
+    var headers = interfaceUtils._mGenUIFuncs.getTabDropDowns(dataset);
+    markerFile.expectedHeader = Object.assign({}, ...Object.keys(headers).map((k) => ({[k]: headers[k].value})));
+    var radios = interfaceUtils._mGenUIFuncs.getTabRadiosAndChecks(dataset);
+    markerFile.expectedRadios = Object.assign({}, ...Object.keys(radios).map((k) => ({[k]: radios[k].checked})));
+}
+
 projectUtils.makeButtonFromTabAux = function (dataset, csvFile, title, comment) {
     buttonsDict = {};
 
@@ -220,7 +228,6 @@ projectUtils.loadProjectFile = function() {
         // here we tell the reader what to do when it's done reading...
         reader.onload = readerEvent => {
             var content = readerEvent.target.result; // this is the content!
-            console.log( content );
             projectUtils.loadProject(JSON.parse(content));
         }
     }
@@ -265,7 +272,6 @@ projectUtils.loadProjectFileFromServer = function(path) {
                 </div>
             </div>
         </div>`;
-        console.log(div)
         document.body.appendChild(div);
     }
     
@@ -346,12 +352,17 @@ projectUtils.loadProjectFileFromServer = function(path) {
             if (tab.visible === false) {document.getElementById("title-tab-" + tab.name).style.display="none"}
         });
     }*/
-    console.log("state.regions, state.regions != {}", state.regions, state.regions != {})
+
     if (state.regions && Object.keys(state.regions).length > 0) {
         regionUtils.JSONValToRegions(state.regions);
     }
     if (state.regionFile) {
-        regionUtils.JSONToRegions(state.regionFile);
+        const queryString = window.location.search;
+        const urlParams = new URLSearchParams(queryString);
+        const path = urlParams.get('path')
+        if (path != null) {
+            regionUtils.JSONToRegions(path + "/" + state.regionFile);
+        }
     }
     projectUtils._activeState = state;
     tmapp.fixed_file = "";
@@ -359,7 +370,8 @@ projectUtils.loadProjectFileFromServer = function(path) {
         filterUtils._compositeMode = state.compositeMode;
     }
     if (state.markerFiles) {
-        state.markerFiles.forEach(function(markerFile) {
+        state.markerFiles.forEach(function(markerFile, buttonIndex) {
+            markerFile["fromButton"] = buttonIndex;
             if (markerFile.expectedCSV) {
                 projectUtils.convertOldMarkerFile(markerFile);
                 state.hideTabs = true;
@@ -374,12 +386,12 @@ projectUtils.loadProjectFileFromServer = function(path) {
     }
     if (state.regionFiles) {
         state.regionFiles.forEach(function(regionFile) {
-            interfaceUtils.createDownloadButtonRegions(
-                regionFile.title,
-                regionFile.path,
-                regionFile.comment,
-                regionFile.autoLoad
-            );
+            if( Object.prototype.toString.call( regionFile.path ) === '[object Array]' ) {
+                interfaceUtils.createDownloadDropdownRegions(regionFile);
+            }
+            else {
+                interfaceUtils.createDownloadButtonRegions(regionFile);
+            }
         });
     }
     if (state.filename) {
@@ -390,34 +402,6 @@ projectUtils.loadProjectFileFromServer = function(path) {
         document.getElementById("project_title").href = state.link;
         document.getElementById("project_title").target = "_blank";
     }
-    tmapp.layers = [];
-    subfolder = window.location.pathname.substring(0, window.location.pathname.lastIndexOf('/'));
-    state.layers.forEach(function(layer) {
-        pathname = window.location.pathname.substring(0, window.location.pathname.lastIndexOf('/') + 1);
-        tmapp.layers.push(
-            {name: layer.name, tileSource: layer.tileSource}
-        )
-    });
-    if (state.filters) {
-        filterUtils._filtersUsed = state.filters;
-        $(".filterSelection").prop("checked",false);
-        state.filters.forEach(function(filterused, i) {
-            console.log("#filterCheck_" + filterused, $("#filterCheck_" + filterused));
-            $("#filterCheck_" + filterused).prop("checked",true);
-        });
-    }
-    if (state.layerFilters) {
-        filterUtils._filterItems = state.layerFilters;
-    }
-    tmapp[tmapp["object_prefix"] + "_viewer"].world.removeAll();
-    overlayUtils.addAllLayers();
-    if (state.layerOpacities && state.layerVisibilities) {
-        $(".visible-layers").prop("checked",true);$(".visible-layers").click();
-    }
-    if (state.compositeMode) {
-        filterUtils._compositeMode = state.compositeMode;
-        filterUtils.setCompositeOperation();
-    }
     if (state.settings) {
         state.settings.forEach(function(setting, i) {
             try{
@@ -434,6 +418,41 @@ projectUtils.loadProjectFileFromServer = function(path) {
             interfaceUtils.addMenuItem([menuButton.text], function(){ window.open(menuButton.url, '_self').focus();});
         });
     }
+    projectUtils.loadLayers(state);
+    
+    //tmapp[tmapp["object_prefix"] + "_viewer"].world.resetItems()
+}
+
+/**
+ * This method is used to load the TissUUmaps layers from state */
+ projectUtils.loadLayers = function(state) {
+    tmapp.layers = [];
+    subfolder = window.location.pathname.substring(0, window.location.pathname.lastIndexOf('/'));
+    state.layers.forEach(function(layer) {
+        pathname = window.location.pathname.substring(0, window.location.pathname.lastIndexOf('/') + 1);
+        tmapp.layers.push(
+            {name: layer.name, tileSource: layer.tileSource}
+        )
+    });
+    if (state.filters) {
+        filterUtils._filtersUsed = state.filters;
+        $(".filterSelection").prop("checked",false);
+        state.filters.forEach(function(filterused, i) {
+            $("#filterCheck_" + filterused).prop("checked",true);
+        });
+    }
+    if (state.layerFilters) {
+        filterUtils._filterItems = state.layerFilters;
+    }
+    tmapp[tmapp["object_prefix"] + "_viewer"].world.removeAll();
+    overlayUtils.addAllLayers();
+    if (state.layerOpacities && state.layerVisibilities) {
+        $(".visible-layers").prop("checked",true);$(".visible-layers").click();
+    }
+    if (state.compositeMode) {
+        filterUtils._compositeMode = state.compositeMode;
+        filterUtils.setCompositeOperation();
+    }
     /*if (projectUtils._hideCSVImport) {
         document.getElementById("ISS_data_panel").style.display="none";
     }*/
@@ -446,7 +465,6 @@ projectUtils.loadProjectFileFromServer = function(path) {
         if (state.boundingBox) {
             setTimeout(function() {
                 tmapp[tmapp["object_prefix"] + "_viewer"].viewport.fitBounds(new OpenSeadragon.Rect(state.boundingBox.x, state.boundingBox.y, state.boundingBox.width, state.boundingBox.height), false);
-                console.log("Changing BBox")
             },1000);
         }
         if (state.compositeMode) {
@@ -455,7 +473,6 @@ projectUtils.loadProjectFileFromServer = function(path) {
         }
         if (state.layerOpacities && state.layerVisibilities) {
             tmapp.layers.forEach(function(layer, i) {
-                console.log("state.layerOpacities[i]",i,state.layerOpacities[i])
                 $("#opacity-layer-"+i).val(state.layerOpacities[i]);
                 if (state.layerVisibilities[i] != 0) {
                     $("#visible-layer-"+i).click();
@@ -463,8 +480,6 @@ projectUtils.loadProjectFileFromServer = function(path) {
             });
         }
     },300);
-    
-    //tmapp[tmapp["object_prefix"] + "_viewer"].world.resetItems()
 }
 
 projectUtils.convertOldMarkerFile = function(markerFile) {
@@ -532,8 +547,10 @@ projectUtils.convertOldMarkerFile = function(markerFile) {
                 markerFile.expectedRadios.cb_gr_dict = true;
                 markerFile.expectedHeader.cb_gr_dict = JSON.stringify(setting.value);
             }
-            if (setting.module == "glUtils" && setting.function == "_markerOpacity")
+            if (setting.module == "glUtils" && setting.function == "_markerOpacity") {
                 markerFile.expectedHeader.opacity = setting.value;
+                setting.function = "_markerOpacityOld"
+            }
             if (setting.module == "HTMLElementUtils" && setting.function == "_colorsperbarcode") {
                 markerFile.expectedRadios.cb_gr = true;
                 markerFile.expectedRadios.cb_gr_rand = false;
@@ -545,7 +562,6 @@ projectUtils.convertOldMarkerFile = function(markerFile) {
     }
     delete markerFile.expectedCSV;
     markerFile["hideSettings"] = true;
-    console.log(markerFile);
 }
 
 /**
@@ -613,4 +629,4 @@ projectUtils.addLegend = function (htmlContent) {
     elt = document.getElementById("markerLegend");
     elt.style.display="block";
     elt.innerHTML = htmlContent;
-}
\ No newline at end of file
+}
