@@ -34,7 +34,8 @@ from flask import (
     request,
     Response,
     send_from_directory,
-    redirect
+    redirect,
+    _request_ctx_stack
 )
 
 from tissuumaps.flask_filetree import filetree
@@ -77,9 +78,12 @@ def authenticate():
 def requires_auth(f):
     @wraps(f)
     def decorated(*args, **kwargs):
-        if not "path" in kwargs.keys():
-            return f(*args, **kwargs)
-        path = os.path.abspath(os.path.join(app.basedir, kwargs["path"]))
+        if _request_ctx_stack.top.request.args.get('path'):
+            path = os.path.abspath(os.path.join(app.basedir, _request_ctx_stack.top.request.args.get('path'), "fake"))
+        elif not "path" in kwargs.keys():
+            path = getPathFromReferrer(_request_ctx_stack.top.request, "")
+        else:
+            path = os.path.abspath(os.path.join(app.basedir, kwargs["path"]))
         activeFolder = os.path.dirname(path)
         while os.path.dirname(activeFolder) != activeFolder and not os.path.isfile(
             activeFolder + "/auth"
@@ -138,6 +142,7 @@ class ImageConverter:
                         tile=True,
                         tile_width=256,
                         tile_height=256,
+                        compression='jpeg',
                         properties=True
                     )
                 except:
@@ -280,7 +285,8 @@ def _setup():
 @app.errorhandler(404)
 def page_not_found(e):
     # note that we set the 404 status explicitly
-    return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"], message="Impossible to load this file", readOnly=app.config["READ_ONLY"])
+    #return render_template("tissuumaps.html", isStandalone=app.config["isStandalone"], message="Impossible to load this file", readOnly=app.config["READ_ONLY"])
+    return redirect("/404"), 404, {"Refresh": "1; url=/404"}
 
 
 def _get_slide(path, originalPath=None):
@@ -304,8 +310,7 @@ def _get_slide(path, originalPath=None):
                 + os.path.splitext(os.path.basename(path))[0]
                 + ".tif"
             )
-            if not os.path.isdir(os.path.dirname(path) + "/.tissuumaps/"):
-                os.makedirs(os.path.dirname(path) + "/.tissuumaps/")
+            os.makedirs(os.path.dirname(path) + "/.tissuumaps/",exist_ok=True)
             tifpath = ImageConverter(path, newpath).convert()
             return _get_slide(tifpath, path)
         except:
@@ -371,6 +376,11 @@ def getPathFromReferrer(request, filename):
     return path
 
 
+@app.route("/<path:path>/<string:filename>.tmap", methods=["GET", "POST"])
+@requires_auth
+def tmapFile_old(path, filename):
+    return redirect(url_for("tmapFile", filename=filename) + "?path=" + path)
+
 @app.route("/<string:filename>.tmap", methods=["GET", "POST"])
 @requires_auth
 def tmapFile(filename):
@@ -410,13 +420,15 @@ def tmapFile(filename):
         )
 
 
-@app.route("/<path:filename>.csv")
+@app.route("/<path:completePath>.csv")
 @requires_auth
-def csvFile(filename):
-    completePath = getPathFromReferrer(request, filename) + ".csv"
+def csvFile(completePath):
+    completePath = os.path.join(app.basedir, completePath + ".csv")
     directory = os.path.dirname(completePath)
     filename = os.path.basename(completePath)
+    print ("completePath", completePath, directory, filename, os.path.isfile(completePath))
     if os.path.isfile(completePath):
+        return send_from_directory(directory, filename)
         # Temporary fix for gz files without csv
         if os.path.isfile(completePath + ".gz"):
             os.rename(completePath + ".gz", completePath + ".cgz")
@@ -445,10 +457,10 @@ def csvFile(filename):
         abort(404)
 
 
-@app.route("/<path:filename>.json")
+@app.route("/<path:completePath>.json")
 @requires_auth
-def jsonFile(filename):
-    completePath = getPathFromReferrer(request, filename) + ".json"
+def jsonFile(completePath):
+    completePath = os.path.join(app.basedir, completePath + ".json")
     directory = os.path.dirname(completePath)
     filename = os.path.basename(completePath)
     if os.path.isfile(completePath):
@@ -457,10 +469,9 @@ def jsonFile(filename):
         abort(404)
 
 
-@app.route("/<path:filename>.dzi")
+@app.route("/<path:path>.dzi")
 @requires_auth
-def dzi(filename):
-    path = getPathFromReferrer(request, filename)
+def dzi(path):
     # Check if a .dzi file exists, else use OpenSlide:
     if os.path.isfile(path + ".dzi"):
         directory = os.path.dirname(path)
@@ -473,10 +484,9 @@ def dzi(filename):
     return resp
 
 
-@app.route("/<path:filename>.dzi/info")
+@app.route("/<path:path>.dzi/info")
 @requires_auth
-def dzi_asso(filename):
-    path = getPathFromReferrer(request, filename)
+def dzi_asso(path):
     slide = _get_slide(path)
     associated_images = []
     for key, im in slide.associated_images.items():
@@ -494,9 +504,8 @@ def dzi_asso(filename):
 
 
 
-@app.route("/<path:filename>_files/<int:level>/<int:col>_<int:row>.<format>")
-def tile(filename, level, col, row, format):
-    path = getPathFromReferrer(request, filename)
+@app.route("/<path:path>_files/<int:level>/<int:col>_<int:row>.<format>")
+def tile(path, level, col, row, format):
     if os.path.isfile( f"{path}_files/{level}/{col}_{row}.{format}"):
         directory = os.path.dirname(f"{path}_files/{level}/{col}_{row}.{format}")
         filename = os.path.basename(f"{path}_files/{level}/{col}_{row}.{format}")
@@ -521,10 +530,9 @@ def tile(filename, level, col, row, format):
     return resp
 
 @app.route(
-    "/<path:filename>.dzi/<path:associated_name>_files/<int:level>/<int:col>_<int:row>.<format>"
+    "/<path:path>.dzi/<path:associated_name>_files/<int:level>/<int:col>_<int:row>.<format>"
 )
-def tile_asso(filename, associated_name, level, col, row, format):
-    path = getPathFromReferrer(request, filename)
+def tile_asso(path, associated_name, level, col, row, format):
     slide = _get_slide(path).associated_images[associated_name]
     format = format.lower()
     if format != "jpeg" and format != "png":
